==> scanbot_sdk-2.6.0-beta4.tar.gz: lib/document_scan_data.dart <==
import 'dart:ui';

import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/common_data.dart' as prefix0;
import 'package:scanbot_sdk/sdk_utils.dart';

import 'common_data.dart';

part 'document_scan_data.g.dart';

/// Scanned document return class from document scanner rtu-ui component
@JsonSerializable(
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DocumentScanningResult extends Result {
  List<Page> pages = <Page>[];

  DocumentScanningResult(this.pages);

  DocumentScanningResult.error(String message) {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  DocumentScanningResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  factory DocumentScanningResult.fromJson(Map<String, dynamic> json) =>
      _$DocumentScanningResultFromJson(json);

  Map<String, dynamic> toJson() => _$DocumentScanningResultToJson(this);
}

/// Document scanner configuration class. All UI configuration options are optional.
@JsonSerializable( includeIfNull: false, explicitToJson: true)
class DocumentScannerConfiguration {
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarBackgroundColor;

  /// The color of all inactive toggle buttons in the toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsInactiveColor;

  /// The color of all active toggle buttons in the toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsActiveColor;

  /// The color of the camera background (relevant only when the camera preview mode is CameraPreviewMode.FIT_IN).
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? cameraBackgroundColor;

  /// The background color of the user guidance hints.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? userGuidanceBackgroundColor;

  /// The text color of the user guidance hints.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? userGuidanceTextColor;

  /// The background color of the bottom shutter-bar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? bottomBarBackgroundColor;

  /// The color of the title of all buttons in the bottom shutter-bar (Cancel button, etc.),
  /// as well as the camera permission prompt button.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? bottomBarButtonsColor;

  /// The foreground color of the shutter button in auto-snapping mode.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? shutterButtonAutoInnerColor;

  /// The background color of the shutter button in auto-snapping mode.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? shutterButtonAutoOuterColor;

  /// The background color of the shutter button in manual mode.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? shutterButtonManualOuterColor;

  /// The foreground color of the shutter button in manual mode.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? shutterButtonManualInnerColor;

  /// The color of the detected document outline when the document's angle, size or aspect ratio
  /// is not yet acceptable
  /// (All detection statuses in net.doo.snap.lib.detector.DetectionResult that have the OK_BUT_XXX prefix).
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonColor;

  /// The color of the detected document outline when we are ready to snap net.doo.snap.lib.detector.DetectionResult.OK.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonColorOK;

  /// The background color of the detected document outline when the document's angle, size or aspect ratio
  /// is not yet acceptable
  /// (All net.doo.snap.lib.detector.DetectionResult with OK_BUT_XXX).
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonBackgroundColor;

  /// The background color of the detected document outline when we are ready to snap net.doo.snap.lib.detector.DetectionResult.OK.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonBackgroundColorOK;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? shutterButtonIndicatorColor;

  /// Controls whether the multi-page toggle button is hidden or not.
  bool? multiPageButtonHidden;

  /// Controls whether the flash toggle button is hidden or not.
  bool? flashButtonHidden;

  /// Hides the shutter button if set to TRUE. Shows it otherwise. Defaults to FALSE.
  /// If set to TRUE, auto-snapping is enabled and the property autoSnappingEnabled of the behaviour configuration will
  /// have no effect.
  /// Also, the auto-snapping button will be hidden.
  bool? shutterButtonHidden;

  /// Controls whether the auto-snapping toggle button is hidden or not.
  bool? autoSnappingButtonHidden;

  bool? cancelButtonHidden;

  /// Width of the detected document outline.
  int? polygonLineWidth;

  /// Max number of pages available to scan;
  int? maxNumberOfPages;

  /// The minimum score in percent (0 - 100) of the perspective distortion to accept a detected document.
  /// Default is 75.0.
  double? acceptedAngleScore;

  /// The minimum document width or height in percent (0 - 100) of the screen size to accept a detected document.
  /// Default is 80.0.
  double? acceptedSizeScore;

  /// Controls the auto-snapping speed. Sensitivity must be within the 0..1 range.
  /// A value of 1.0 triggers automatic capturing immediately, a value of 0.0 delays the automatic capturing by 3 seconds.
  /// The default value is 0.66 (2 seconds)
  double? autoSnappingSensitivity;

  /// Limits the maximum size of the document image. If width or height are zero, this property is effectively ignored.
  prefix0.Size? documentImageSizeLimit;

  /// Preview mode of the camera: Fit-In or Fill-In.
  /// Optional, default is Fit-In.
  CameraPreviewMode? cameraPreviewMode;

  /// Orientation lock mode of the camera: PORTRAIT or LANDSCAPE.
  /// By default the camera orientation is not locked.
  CameraOrientationMode? orientationLockMode;

  /// Sets whether to ignore the net.doo.snap.lib.detector.DetectionResult.OK_BUT_BAD_ASPECT_RATIO detection status.
  /// By default BadAspectRatio is not ignored.
  bool? ignoreBadAspectRatio;

  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  /// Controls multi-page mode. When enabled, the user can take multiple document photos before
  /// closing the screen by tapping the page counter button. When disabled, the screen will be
  /// closed immediately after the first document photo is made.
  /// The default value is FALSE.
  bool? multiPageEnabled;

  /// When auto-snapping is enabled the document scanner will take a photo automatically
  /// when a document is detected, conditions are good and the auto-snapping time-out elapses. In this
  /// mode the user can still tap the shutter button to snap a document.
  bool? autoSnappingEnabled;

  String? multiPageButtonTitle;

  /// Title of the cancel button.
  String? cancelButtonTitle;

  /// Title of the flash toggle button.
  String? flashButtonTitle;

  /// Title of the auto-snapping toggle button.
  String? autoSnappingButtonTitle;

  /// Title suffix of the button that finishes the document scanning when multi-page scanning is enabled.
  /// The button's title has the format "# Pages", where # shows the number of images captured up to now and the
  /// suffix "Pages" is set using this method.
  String? pageCounterButtonTitle;

  /// The text being displayed on the user-guidance label
  /// when the scanner's energy saver is activated.
  /// iOS only.
  String? textHintEnergySavingActive;

  /// Text hint that will be shown when the current detection status
  /// is net.doo.snap.lib.detector.DetectionResult.ERROR_NOTHING_DETECTED
  String? textHintNothingDetected;

  /// Text hint that will be shown when the current detection status
  /// is net.doo.snap.lib.detector.DetectionResult.ERROR_TOO_NOISY
  String? textHintTooNoisy;

  /// Text hint that will be shown when the current detection status
  /// is net.doo.snap.lib.detector.DetectionResult.ERROR_TOO_DARK
  String? textHintTooDark;

  /// Text hint that will be shown when the current detection status
  /// is net.doo.snap.lib.detector.DetectionResult.OK_BUT_BAD_ANGLES
  String? textHintBadAngles;

  /// Text hint that will be shown when the current detection status
  /// is net.doo.snap.lib.detector.DetectionResult.OK_BUT_BAD_ASPECT_RATIO
  String? textHintBadAspectRatio;

  /// Text hint that will be shown when the current detection status
  /// is net.doo.snap.lib.detector.DetectionResult.OK_BUT_TOO_SMALL
  String? textHintTooSmall;

  /// The background color of the top toolbar.
  String? textHintOffCenter;

  /// Text hint that will be shown when the current detection
  /// status is net.doo.snap.lib.detector.DetectionResult.OK
  String? textHintOK;

  /// String being displayed on the label describing that app is in split mode
  /// and needs to go fullscreen to work with camera. (iOS-only)
  String? cameraUnavailableExplanationText;

  /// Title of the button that opens the screen where the user can allow
  /// the usage of the camera by the app.
  String? enableCameraButtonTitle;

  /// Text that will be displayed when the app is not allowed to use the camera,
  /// prompting the user to enable the usage of the camera.
  String? enableCameraExplanationText;

  DocumentScannerConfiguration(
      {this.topBarBackgroundColor,
      this.topBarButtonsInactiveColor,
      this.topBarButtonsActiveColor,
      this.shutterButtonAutoInnerColor,
      this.shutterButtonAutoOuterColor,
      this.shutterButtonManualOuterColor,
      this.shutterButtonManualInnerColor,
      this.shutterButtonIndicatorColor,
      this.flashButtonHidden,
      this.shutterButtonHidden,
      this.autoSnappingButtonHidden,
      this.multiPageButtonHidden,
      this.cancelButtonHidden,
      this.bottomBarBackgroundColor,
      this.bottomBarButtonsColor,
      this.polygonColor,
      this.polygonColorOK,
      this.polygonBackgroundColor,
      this.polygonBackgroundColorOK,
      this.userGuidanceBackgroundColor,
      this.userGuidanceTextColor,
      this.cameraBackgroundColor,
      this.polygonLineWidth,
      this.multiPageEnabled,
      this.autoSnappingEnabled,
      this.flashEnabled,
      this.acceptedAngleScore,
      this.acceptedSizeScore,
      this.autoSnappingSensitivity,
      this.documentImageSizeLimit,
      this.cameraPreviewMode,
      this.orientationLockMode,
      this.ignoreBadAspectRatio,
      this.cancelButtonTitle,
      this.flashButtonTitle,
      this.autoSnappingButtonTitle,
      this.multiPageButtonTitle,
      this.pageCounterButtonTitle,
      this.textHintEnergySavingActive,
      this.textHintNothingDetected,
      this.textHintTooNoisy,
      this.textHintTooDark,
      this.textHintBadAngles,
      this.textHintBadAspectRatio,
      this.textHintTooSmall,
      this.textHintOffCenter,
      this.textHintOK,
      this.cameraUnavailableExplanationText,
      this.maxNumberOfPages,
      this.enableCameraButtonTitle,
      this.enableCameraExplanationText});

  factory DocumentScannerConfiguration.fromJson(Map<String, dynamic> json) =>
      _$DocumentScannerConfigurationFromJson(json);

  Map<String, dynamic> toJson() => _$DocumentScannerConfigurationToJson(this);
}

==> scanbot_sdk-2.10.0-beta4.tar.gz: lib/document_scan_data.dart <==
import 'dart:ui';

import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/json/common_data.dart' as prefix0;
import 'package:scanbot_sdk/sdk_utils.dart';

import 'json/common_data.dart';

part 'document_scan_data.g.dart';

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: false)
class DocumentContourScanningResult {
  List<PolygonPoint>? polygon;
  DetectionResult detectionResult;

  DocumentContourScanningResult(this.polygon, this.detectionResult);

  factory DocumentContourScanningResult.fromJson(Map<String, dynamic> json) =>
      _$DocumentContourScanningResultFromJson(json);
}

enum DetectionResult {
  OK,

  OK_BUT_TOO_SMALL,

  OK_BUT_BAD_ANGLES,

  OK_BUT_BAD_ASPECT_RATIO,

  OK_OFF_CENTER,

  OK_BARCODE,

  ERROR_NOTHING_DETECTED,

  ERROR_TOO_DARK,

  ERROR_TOO_NOISY
}

/// Scanned document return class from document scanner rtu-ui component
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DocumentScanningResult extends Result {
  List<Page> pages = <Page>[];

  DocumentScanningResult(this.pages);

  DocumentScanningResult.error(String message) {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  DocumentScanningResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  factory DocumentScanningResult.fromJson(Map<String, dynamic> json) =>
      _$DocumentScanningResultFromJson(json);

  Map<String, dynamic> toJson() => _$DocumentScanningResultToJson(this);
}

/// Document scanner configuration class. All UI configuration options are optional.
@JsonSerializable(includeIfNull: false, explicitToJson: true)
class DocumentScannerConfiguration {
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarBackgroundColor;

  /// The color of all inactive toggle buttons in the toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsInactiveColor;

  /// The color of all active toggle buttons in the toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsActiveColor;

  /// The color of the camera background (relevant only when the camera preview mode is CameraPreviewMode.FIT_IN).
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? cameraBackgroundColor;

  /// The background color of the user guidance hints.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? userGuidanceBackgroundColor;

  /// The text color of the user guidance hints.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? userGuidanceTextColor;

  /// The background color of the bottom shutter-bar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? bottomBarBackgroundColor;

  /// The color of the title of all buttons in the bottom shutter-bar (Cancel button, etc.),
  /// as well as the camera permission prompt button.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? bottomBarButtonsColor;

  /// The foreground color of the shutter button in auto-snapping mode.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? shutterButtonAutoInnerColor;

  /// The background color of the shutter button in auto-snapping mode.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? shutterButtonAutoOuterColor;

  /// The background color of the shutter button in manual mode.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? shutterButtonManualOuterColor;

  /// The foreground color of the shutter button in manual mode.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? shutterButtonManualInnerColor;

  /// The color of the detected document outline when the document's angle, size or aspect ratio
  /// is not yet acceptable
  /// (All detection statuses in net.doo.snap.lib.detector.DetectionResult that have the OK_BUT_XXX prefix).
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonColor;

  /// The color of the detected document outline when we are ready to snap net.doo.snap.lib.detector.DetectionResult.OK.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonColorOK;

  /// The background color of the detected document outline when the document's angle, size or aspect ratio
  /// is not yet acceptable
  /// (All net.doo.snap.lib.detector.DetectionResult with OK_BUT_XXX).
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonBackgroundColor;

  /// The background color of the detected document outline when we are ready to snap net.doo.snap.lib.detector.DetectionResult.OK.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonBackgroundColorOK;

  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? shutterButtonIndicatorColor;

  /// Controls whether the multi-page toggle button is hidden or not.
  bool? multiPageButtonHidden;

  /// Controls whether the flash toggle button is hidden or not.
  bool? flashButtonHidden;

  /// Hides the shutter button if set to TRUE. Shows it otherwise. Defaults to FALSE.
  /// If set to TRUE, auto-snapping is enabled and the property autoSnappingEnabled of the behaviour configuration will
  /// have no effect.
  /// Also, the auto-snapping button will be hidden.
  bool? shutterButtonHidden;

  /// Controls whether the auto-snapping toggle button is hidden or not.
  bool? autoSnappingButtonHidden;

  bool? cancelButtonHidden;

  /// Width of the detected document outline.
  int? polygonLineWidth;

  /// Max number of pages available to scan;
  int? maxNumberOfPages;

  /// The minimum score in percent (0 - 100) of the perspective distortion to accept a detected document.
  /// Default is 75.0.
  double? acceptedAngleScore;

  /// The minimum document width or height in percent (0 - 100) of the screen size to accept a detected document.
  /// Default is 80.0.
  double? acceptedSizeScore;

  /// Controls the auto-snapping speed. Sensitivity must be within the 0..1 range.
  /// A value of 1.0 triggers automatic capturing immediately, a value of 0.0 delays the automatic capturing by 3 seconds.
  /// The default value is 0.66 (2 seconds)
  double? autoSnappingSensitivity;

  /// Limits the maximum size of the document image. If width or height are zero, this property is effectively ignored.
  prefix0.Size? documentImageSizeLimit;

  /// Preview mode of the camera: Fit-In or Fill-In.
  /// Optional, default is Fit-In.
  CameraPreviewMode? cameraPreviewMode;

  /// Orientation lock mode of the camera: PORTRAIT or LANDSCAPE.
  /// By default the camera orientation is not locked.
  OrientationLockMode? orientationLockMode;

  /// Sets whether to ignore the net.doo.snap.lib.detector.DetectionResult.OK_BUT_BAD_ASPECT_RATIO detection status.
  /// By default BadAspectRatio is not ignored.
  bool? ignoreBadAspectRatio;

  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  /// Controls multi-page mode. When enabled, the user can take multiple document photos before
  /// closing the screen by tapping the page counter button. When disabled, the screen will be
  /// closed immediately after the first document photo is made.
  /// The default value is FALSE.
  bool? multiPageEnabled;

  /// When auto-snapping is enabled the document scanner will take a photo automatically
  /// when a document is detected, conditions are good and the auto-snapping time-out elapses. In this
  /// mode the user can still tap the shutter button to snap a document.
  bool? autoSnappingEnabled;

  String? multiPageButtonTitle;

  /// Title of the cancel button.
  String? cancelButtonTitle;

  /// Title of the flash toggle button.
  String? flashButtonTitle;

  /// Title of the auto-snapping toggle button.
  String? autoSnappingButtonTitle;

  /// Title suffix of the button that finishes the document scanning when multi-page scanning is enabled.
  /// The button's title has the format "# Pages", where # shows the number of images captured up to now and the
  /// suffix "Pages" is set using this method.
  String? pageCounterButtonTitle;

  /// The text being displayed on the user-guidance label
  /// when the scanner's energy saver is activated.
  /// iOS only.
  String? textHintEnergySavingActive;

  /// Text hint that will be shown when the current detection status
  /// is net.doo.snap.lib.detector.DetectionResult.ERROR_NOTHING_DETECTED
  String? textHintNothingDetected;

  /// Text hint that will be shown when the current detection status
  /// is net.doo.snap.lib.detector.DetectionResult.ERROR_TOO_NOISY
  String? textHintTooNoisy;

  /// Text hint that will be shown when the current detection status
  /// is net.doo.snap.lib.detector.DetectionResult.ERROR_TOO_DARK
  String? textHintTooDark;

  /// Text hint that will be shown when the current detection status
  /// is net.doo.snap.lib.detector.DetectionResult.OK_BUT_BAD_ANGLES
  String? textHintBadAngles;

  /// Text hint that will be shown when the current detection status
  /// is net.doo.snap.lib.detector.DetectionResult.OK_BUT_BAD_ASPECT_RATIO
  String? textHintBadAspectRatio;

  /// Text hint that will be shown when the current detection status
  /// is net.doo.snap.lib.detector.DetectionResult.OK_BUT_TOO_SMALL
  String? textHintTooSmall;

  /// The background color of the top toolbar.
  String? textHintOffCenter;

  /// Text hint that will be shown when the current detection
  /// status is net.doo.snap.lib.detector.DetectionResult.OK
  String? textHintOK;

  /// String being displayed on the label describing that app is in split mode
  /// and needs to go fullscreen to work with camera. (iOS-only)
  String? cameraUnavailableExplanationText;

  /// Title of the button that opens the screen where the user can allow
  /// the usage of the camera by the app.
  String? enableCameraButtonTitle;

  /// Text that will be displayed when the app is not allowed to use the camera,
  /// prompting the user to enable the usage of the camera.
  String? enableCameraExplanationText;

  DocumentScannerConfiguration(
      {this.topBarBackgroundColor,
      this.topBarButtonsInactiveColor,
      this.topBarButtonsActiveColor,
      this.shutterButtonAutoInnerColor,
      this.shutterButtonAutoOuterColor,
      this.shutterButtonManualOuterColor,
      this.shutterButtonManualInnerColor,
      this.shutterButtonIndicatorColor,
      this.flashButtonHidden,
      this.shutterButtonHidden,
      this.autoSnappingButtonHidden,
      this.multiPageButtonHidden,
      this.cancelButtonHidden,
      this.bottomBarBackgroundColor,
      this.bottomBarButtonsColor,
      this.polygonColor,
      this.polygonColorOK,
      this.polygonBackgroundColor,
      this.polygonBackgroundColorOK,
      this.userGuidanceBackgroundColor,
      this.userGuidanceTextColor,
      this.cameraBackgroundColor,
      this.polygonLineWidth,
      this.multiPageEnabled,
      this.autoSnappingEnabled,
      this.flashEnabled,
      this.acceptedAngleScore,
      this.acceptedSizeScore,
      this.autoSnappingSensitivity,
      this.documentImageSizeLimit,
      this.cameraPreviewMode,
      this.orientationLockMode,
      this.ignoreBadAspectRatio,
      this.cancelButtonTitle,
      this.flashButtonTitle,
      this.autoSnappingButtonTitle,
      this.multiPageButtonTitle,
      this.pageCounterButtonTitle,
      this.textHintEnergySavingActive,
      this.textHintNothingDetected,
      this.textHintTooNoisy,
      this.textHintTooDark,
      this.textHintBadAngles,
      this.textHintBadAspectRatio,
      this.textHintTooSmall,
      this.textHintOffCenter,
      this.textHintOK,
      this.cameraUnavailableExplanationText,
      this.maxNumberOfPages,
      this.enableCameraButtonTitle,
      this.enableCameraExplanationText});

  factory DocumentScannerConfiguration.fromJson(Map<String, dynamic> json) =>
      _$DocumentScannerConfigurationFromJson(json);

  Map<String, dynamic> toJson() => _$DocumentScannerConfigurationToJson(this);
}
